==> nextcloud-app-spreed-1:15.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/es_MX.js <==
OC.L10N.register(
    "spreed",
    {
    "a conversation" : "una conversación",
    "(Duration %s)" : "(Duración %s)",
    "You attended a call with {user1}" : "Tomaste una llamda con {user1}",
    "_%n guest_::_%n guests_" : ["%n inivitado","%n inivitados","%n inivitados"],
    "You attended a call with {user1} and {user2}" : "Tuviste una llamada con {user1} y {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Tuviste una llamada con {user1}, {user2} y {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Tuviste una llamada con {user1}, {user2}, {user3} y {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Tuviste una llamada con {user1}, {user2}, {user3}, {user4} y {user5}",
    "_%n other_::_%n others_" : ["%n otro","otros %n","otros %n"],
    "{actor} invited you to {call}" : "{actor} te ha invitado a {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Fuiste invitado a una<strong>conversación</strong> o tuviste una <strong>llamada</strong>",
    "Talk" : "Hablar",
    "Guest" : "Invitado",
    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Bienvenido a Nextcloud Talk!\nEn esta conversación se te informará sobre nuevas características disponibles en Nextcloud Talk.",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge y Safari ahora pueden ser usados para participar en llamdas de audio y video llamadas",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Ahora puedes notificar a todos los participantes comentando \"@all\" en el chat",
    "- With the \"arrow-up\" key you can repost your last message" : "- Puedes reenviar tu último mensaje con la tecla \"flecha arriba\"",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk ahora puede recibir comandos, envia \"/help\" como mensaje en el chat para ver si tu administrador configuro algunos",
    "- With projects you can create quick links between conversations, files and other items" : "- Con projects puedes crear ligas entre conversaciones, archivos y otros artículos.",
    "- You can now mention guests in the chat" : "- Ahora puedes mencionar a invitados en el chat",
    "There are currently no commands available." : "No hay comandos disponibles actualmente",
    "The command does not exist" : "El comando no existe",
    "An error occurred while running the command. Please ask an administrator to check the logs." : "Ocurrió un error al ejecutar el comando. Por favor solicite al administrador revisar los logs",
    "Talk updates ✅" : "Actualizaciones de Talk  ✅",
    "{actor} created the conversation" : "{actor} creó la conversación",
    "You created the conversation" : "Creaste la conversación",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} renombró la conversación de \"%1$s\" a \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Renombraste la conversación de \"%1$s\" a \"%2$s\"",
    "{actor} started a call" : "{actor} inició una llamada",
    "You started a call" : "Iniciaste una llamada",
    "{actor} joined the call" : "{actor} se unió a la llamada",
    "You joined the call" : "Te uniste a la llamada",
    "{actor} left the call" : "{actor} abandonó la llamada",
    "You left the call" : "Abandonaste la llamada",
    "{actor} unlocked the conversation" : "{actor} desbloqueó la conversación",
    "You unlocked the conversation" : "Desbloqueaste la conversación",
    "{actor} locked the conversation" : "{actor} bloqueó la conversación",
    "You locked the conversation" : "Bloqueaste la conversación",
    "The conversation is now open to everyone" : "La conversación está abierta para todos",
    "{actor} opened the conversation to everyone" : "{actor} abrió la conversación para todos",
    "You opened the conversation to everyone" : "Abriste la conversación para todos",
    "{actor} restricted the conversation to moderators" : "{actor} restringió la conversación a moderadores",
    "You restricted the conversation to moderators" : "Restringiste la conversación a moderadores",
    "{actor} allowed guests" : "{actor} permitió a invitados",
    "You allowed guests" : "Permitiste a invitados",
    "{actor} disallowed guests" : "{actor} restringió a invitados",
    "You disallowed guests" : "Restringiste a invitados",
    "{actor} set a password" : "{actor} configuró una contraseña",
    "You set a password" : "Configuraste una contraseña",
    "{actor} removed the password" : "{actor} eliminó la contraseña",
    "You removed the password" : "Eliminaste la contraseña",
    "{actor} added {user}" : "{actor} agregó a {user}",
    "You joined the conversation" : "Te uniste a la conversación",
    "{actor} joined the conversation" : "{actor} se unió a la conversación",
    "You added {user}" : "Agregaste a  {user}",
    "{actor} added you" : "{actor} te agregó",
    "You left the conversation" : "Abandonaste la conversación",
    "{actor} left the conversation" : "{actor} abandonó la conversación",
    "{actor} removed {user}" : "{actor} eliminó a {user}",
    "You removed {user}" : "Eliminaste a {user}",
    "{actor} removed you" : "{actor} te eliminó",
    "{actor} promoted {user} to moderator" : "{actor} promovió a {user} a moderador",
    "You promoted {user} to moderator" : "Promoviste a  {user} a moderador",
    "{actor} promoted you to moderator" : "{actor} te promovió a moderador",
    "{actor} demoted {user} from moderator" : "{actor} degradó a {user} de moderador",
    "You demoted {user} from moderator" : "Degradaste a {user} de moderador",
    "{actor} demoted you from moderator" : "{actor} te degradó de moderador",
    "{actor} shared a file which is no longer available" : "{actor} compartió un archivo que ya no está disponible",
    "You shared a file which is no longer available" : "Compartiste un archivo que ya no está disponible",
    "%s (guest)" : "%s (invitado)",
    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Llamada con %n invitado (Duración {duration})","Llamada con %n invitados (Duración {duration})","Llamada con %n invitados (Duración {duration})"],
    "Call with {user1} and {user2} (Duration {duration})" : "Llamada con {user1} y {user2} (Duración {duration})",
    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Llamada con {user1}, {user2} y {user3} (Duración {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Llamada con {user1}, {user2}, {user3} y {user4} (Duración {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Llamada con {user1}, {user2}, {user3}, {user4} y {user5} (Duración {duration})",
    "Talk to %s" : "Hablar con %s",
    "File is not shared, or shared but not with the user" : "Archivo no compartido, o compartido pero no con el usuario.",
    "File is too big" : "El archivo es demasiado grande",
    "Invalid file provided" : "Se proporcionó un archivo invalido",
    "Invalid image" : "Imagen inválida",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "An error occurred. Please contact your admin." : "Se presentó un error. Por favor contacta a tu adminsitrador. ",
    "%s invited you to a conversation." : "%s te invitó a una conversación",
    "You were invited to a conversation." : "fuiste invitado a una conversación",
    "Conversation invitation" : "invitación a una conversación",
    "Click the button below to join." : "Haz click en el botón de abajo para unirte.",
    "Join »%s«" : "Unirse »%s«",
    "Password request: %s" : "Solicitud de Password: %s",
    "Private conversation" : "Conversación privada",
    "Deleted user (%s)" : "Usuario eliminado (%s)",
    "{user} sent you a private message" : "{user} te envió un mensaje privado",
    "{user} mentioned you in a private conversation" : "{user} te mencionó en una conversación privada",
    "{user} invited you to a private conversation" : " {user} te invitó a una conversación privada",
    "Join call" : "Unirse a la llamada",
    "{user} invited you to a group conversation: {call}" : "{user} te invitó a una conversación de grupo: {call}",
    "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
    "Open settings" : "Abrir configuraciones",
    "Conversations" : "Conversaciones",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
    "Leave call" : "Dejar la llamada",
    "This conversation has ended" : "Esta conversación ha terminado",
    "Limit to groups" : "Limitar a grupos",
    "Everyone" : "Todos",
    "Save changes" : "Guardar cambios",
    "Saved!" : "¡Guardado!",
    "None" : "Ninguno",
    "User" : "Usuario",
    "Disabled" : "Deshabilitado",
    "Users" : " Usuarios",
    "Name" : "Nombre",
    "General settings" : "Configuraciones generales",
    "Language" : "Idioma",
    "Country" : "País",
    "Status" : "Estatus",
    "Created at" : "Creado en",
    "Pending" : "Pendiente",
    "Error" : "Error",
    "Blocked" : "Bloqueado",
    "Expired" : "Expirado",
    "Shared secret" : "Secreto compartido",
    "Validate SSL certificate" : "Validar certificado SSL",
    "STUN servers" : "Servidores STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Un servidor STUN se está usando para determinar la IP pública de los participantes que estén detrás de un ruteador. ",
    "TURN server protocols" : "Protocolos del servidor TURN",
    "OK" : "OK",
    "Checking …" : "Verificando ...",
    "Copy link" : "Copiar liga",
    "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
    "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "¡Puedes invitar a otros usando la pestaña de participante de la barra lateral o compartiendo esta liga para invitar a otras personas!",
    "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
    "Dismiss" : "Descartar",
    "Show your screen" : "Mostrar tu pantalla",
    "Stop screensharing" : "Dejar de compartir la pantalla",
    "More actions" : "Más acciones",
    "No audio" : "Sin audio",
    "Mute audio" : "Silenciar audio",
    "Disable video" : "Deshabilitar video",
    "Enable video" : "Habilitar el video",
    "Screensharing options" : "Opciones de compartir pantalla",
    "Enable screensharing" : "Habilitar compartir pantalla",
    "Grid view" : "Vista de cuadrícula",
    "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
    "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
    "Back" : "Atrás",
    "You" : "Tú",
    "Show screen" : "Mostrar pantalla",
    "Favorite" : "Hacer favorito",
    "Restricted" : "Restringido",
    "Description" : "Descripción",
    "Notifications" : "Notificaciones",
    "Leave conversation" : "Dejar la conversación",
    "Delete conversation" : "Borrar conversación",
    "Password protection" : "Protección con contraseña",
    "Enter a password" : "Ingresa una contraseña",
    "Save" : "Guardar",
    "Edit" : "Editar",
    "Delete" : "Eliminar",
    "Password" : "Contraseña",
    "API token" : "Ficha del API",
    "Login" : "Iniciar sesión",
    "Nickname" : "Apodo",
    "Client ID" : "ID del cliente",
    "Calls" : "Llamadas",
    "Remove from favorites" : "Eliminar de favoritos",
    "Add to favorites" : "Agregar a favoritos",
    "Loading" : "Cargando",
    "Groups" : "Grupos",
    "Circles" : "Círculos",
    "Password protect" : "Proteger con contraseña",
    "Close" : "Cerrar",
    "Conversation name" : "Nombre de la conversación",
    "Reply" : "Responder",
    "Contact" : "Contacto",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Create new poll" : "Crear nueva encuesta",
    "New file" : "Archivo nuevo",
    "Settings" : "Configuraciones ",
    "Create poll" : "Crear encuesta",
    "moderator" : "moderador",
    "guest" : "invitado",
    "Demote from moderator" : "Degradar de moderador",
    "Promote to moderator" : "Promover a moderador",
    "Remove participant" : "Eliminar participante",
    "No results" : "Sin resultados",
    "Add users or groups" : "Agregar usuarios o grupos",
    "Participants" : "Participantes",
    "Chat" : "Chat",
    "Details" : "Detalles",
    "Privacy" : "Privacidad",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Search" : "Buscar",
    "Rename conversation" : "Renombrar conversación",
    "Send" : "Enviar",
    "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
    "Media" : "Multimedia",
    "Files" : "Archivos",
    "Polls" : "Encuestas",
    "Locations" : "Ubicaciones",
    "Audio" : "Audio",
    "Other" : "Otro",
    "Do not disturb" : "No molestar",
    "Away" : "Ausente",
    "Default" : "Predeterminado",
    "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
    "Please move your setup to HTTPS" : "Por favor cambia tu configuración a HTTPS",
    "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
    "WebRTC is not supported in your browser" : "WebRTC no está soportado en tu navegador",
    "Please use a different browser like Firefox or Chrome" : "Por favor usa un navegador diferente como Firefox o Chrome",
    "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
    "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
    "TURN server" : "Servidor TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. ",
    "%s Talk on your mobile devices" : "%s Habla en tus dispositivos móviles",
    "Android app" : "Aplicación Android",
    "iOS app" : "Aplicación iOS",
    "Saved" : "Guardado"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-app-spreed-1:17.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/es_MX.js <==
OC.L10N.register(
    "spreed",
    {
    "a conversation" : "una conversación",
    "(Duration %s)" : "(Duración %s)",
    "You attended a call with {user1}" : "Tomaste una llamda con {user1}",
    "_%n guest_::_%n guests_" : ["%n inivitado","%n inivitados","%n inivitados"],
    "You attended a call with {user1} and {user2}" : "Tuviste una llamada con {user1} y {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Tuviste una llamada con {user1}, {user2} y {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Tuviste una llamada con {user1}, {user2}, {user3} y {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Tuviste una llamada con {user1}, {user2}, {user3}, {user4} y {user5}",
    "_%n other_::_%n others_" : ["%n otro","otros %n","otros %n"],
    "{actor} invited you to {call}" : "{actor} te ha invitado a {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Fuiste invitado a una<strong>conversación</strong> o tuviste una <strong>llamada</strong>",
    "Talk" : "Hablar",
    "Guest" : "Invitado",
    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Bienvenido a Nextcloud Talk!\nEn esta conversación se te informará sobre nuevas características disponibles en Nextcloud Talk.",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge y Safari ahora pueden ser usados para participar en llamdas de audio y video llamadas",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Ahora puedes notificar a todos los participantes comentando \"@all\" en el chat",
    "- With the \"arrow-up\" key you can repost your last message" : "- Puedes reenviar tu último mensaje con la tecla \"flecha arriba\"",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk ahora puede recibir comandos, envia \"/help\" como mensaje en el chat para ver si tu administrador configuro algunos",
    "- With projects you can create quick links between conversations, files and other items" : "- Con projects puedes crear ligas entre conversaciones, archivos y otros artículos.",
    "- You can now mention guests in the chat" : "- Ahora puedes mencionar a invitados en el chat",
    "There are currently no commands available." : "No hay comandos disponibles actualmente",
    "The command does not exist" : "El comando no existe",
    "An error occurred while running the command. Please ask an administrator to check the logs." : "Ocurrió un error al ejecutar el comando. Por favor solicite al administrador revisar los logs",
    "Talk updates ✅" : "Actualizaciones de Talk  ✅",
    "{actor} created the conversation" : "{actor} creó la conversación",
    "You created the conversation" : "Creaste la conversación",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} renombró la conversación de \"%1$s\" a \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Renombraste la conversación de \"%1$s\" a \"%2$s\"",
    "{actor} started a call" : "{actor} inició una llamada",
    "You started a call" : "Iniciaste una llamada",
    "{actor} joined the call" : "{actor} se unió a la llamada",
    "You joined the call" : "Te uniste a la llamada",
    "{actor} left the call" : "{actor} abandonó la llamada",
    "You left the call" : "Abandonaste la llamada",
    "{actor} unlocked the conversation" : "{actor} desbloqueó la conversación",
    "You unlocked the conversation" : "Desbloqueaste la conversación",
    "{actor} locked the conversation" : "{actor} bloqueó la conversación",
    "You locked the conversation" : "Bloqueaste la conversación",
    "The conversation is now open to everyone" : "La conversación está abierta para todos",
    "{actor} opened the conversation to everyone" : "{actor} abrió la conversación para todos",
    "You opened the conversation to everyone" : "Abriste la conversación para todos",
    "{actor} restricted the conversation to moderators" : "{actor} restringió la conversación a moderadores",
    "You restricted the conversation to moderators" : "Restringiste la conversación a moderadores",
    "{actor} allowed guests" : "{actor} permitió a invitados",
    "You allowed guests" : "Permitiste a invitados",
    "{actor} disallowed guests" : "{actor} restringió a invitados",
    "You disallowed guests" : "Restringiste a invitados",
    "{actor} set a password" : "{actor} configuró una contraseña",
    "You set a password" : "Configuraste una contraseña",
    "{actor} removed the password" : "{actor} eliminó la contraseña",
    "You removed the password" : "Eliminaste la contraseña",
    "{actor} added {user}" : "{actor} agregó a {user}",
    "You joined the conversation" : "Te uniste a la conversación",
    "{actor} joined the conversation" : "{actor} se unió a la conversación",
    "You added {user}" : "Agregaste a  {user}",
    "{actor} added you" : "{actor} te agregó",
    "You left the conversation" : "Abandonaste la conversación",
    "{actor} left the conversation" : "{actor} abandonó la conversación",
    "{actor} removed {user}" : "{actor} eliminó a {user}",
    "You removed {user}" : "Eliminaste a {user}",
    "{actor} removed you" : "{actor} te eliminó",
    "{actor} promoted {user} to moderator" : "{actor} promovió a {user} a moderador",
    "You promoted {user} to moderator" : "Promoviste a  {user} a moderador",
    "{actor} promoted you to moderator" : "{actor} te promovió a moderador",
    "{actor} demoted {user} from moderator" : "{actor} degradó a {user} de moderador",
    "You demoted {user} from moderator" : "Degradaste a {user} de moderador",
    "{actor} demoted you from moderator" : "{actor} te degradó de moderador",
    "{actor} shared a file which is no longer available" : "{actor} compartió un archivo que ya no está disponible",
    "You shared a file which is no longer available" : "Compartiste un archivo que ya no está disponible",
    "%s (guest)" : "%s (invitado)",
    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Llamada con %n invitado (Duración {duration})","Llamada con %n invitados (Duración {duration})","Llamada con %n invitados (Duración {duration})"],
    "Call with {user1} and {user2} (Duration {duration})" : "Llamada con {user1} y {user2} (Duración {duration})",
    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Llamada con {user1}, {user2} y {user3} (Duración {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Llamada con {user1}, {user2}, {user3} y {user4} (Duración {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Llamada con {user1}, {user2}, {user3}, {user4} y {user5} (Duración {duration})",
    "Talk conversations" : "Conversaciones de Talk",
    "Talk to %s" : "Hablar con %s",
    "File is not shared, or shared but not with the user" : "Archivo no compartido, o compartido pero no con el usuario.",
    "File is too big" : "El archivo es demasiado grande",
    "Invalid file provided" : "Se proporcionó un archivo invalido",
    "Invalid image" : "Imagen inválida",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Talk mentions" : "Menciones en Talk",
    "More unread mentions" : "Más menciones no leídas",
    "%s invited you to a conversation." : "%s te invitó a una conversación",
    "You were invited to a conversation." : "fuiste invitado a una conversación",
    "Conversation invitation" : "invitación a una conversación",
    "Click the button below to join." : "Haz click en el botón de abajo para unirte.",
    "Join »%s«" : "Unirse »%s«",
    "Password request: %s" : "Solicitud de Password: %s",
    "Private conversation" : "Conversación privada",
    "Deleted user (%s)" : "Usuario eliminado (%s)",
    "Dismiss notification" : "Descartar notificación",
    "{user} sent you a private message" : "{user} te envió un mensaje privado",
    "{user} mentioned you in a private conversation" : "{user} te mencionó en una conversación privada",
    "{user} invited you to a private conversation" : " {user} te invitó a una conversación privada",
    "Join call" : "Unirse a la llamada",
    "{user} invited you to a group conversation: {call}" : "{user} te invitó a una conversación de grupo: {call}",
    "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
    "Open settings" : "Abrir configuraciones",
    "Conversations" : "Conversaciones",
    "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
    "Leave call" : "Dejar la llamada",
    "This conversation has ended" : "Esta conversación ha terminado",
    "Limit to groups" : "Limitar a grupos",
    "Everyone" : "Todos",
    "Save changes" : "Guardar cambios",
    "Saved!" : "¡Guardado!",
    "Name" : "Nombre",
    "None" : "Ninguno",
    "User" : "Usuario",
    "Disabled" : "Deshabilitado",
    "Users" : " Usuarios",
    "General settings" : "Configuraciones generales",
    "@-mentions only" : "Solo menciones con @",
    "Language" : "Idioma",
    "Country" : "País",
    "Status" : "Estatus",
    "Created at" : "Creado en",
    "Pending" : "Pendiente",
    "Error" : "Error",
    "Blocked" : "Bloqueado",
    "Expired" : "Expirado",
    "Validate SSL certificate" : "Validar certificado SSL",
    "Shared secret" : "Secreto compartido",
    "STUN servers" : "Servidores STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Un servidor STUN se está usando para determinar la IP pública de los participantes que estén detrás de un ruteador. ",
    "TURN server protocols" : "Protocolos del servidor TURN",
    "OK" : "OK",
    "Checking …" : "Verificando ...",
    "Back" : "Atrás",
    "Confirm" : "Confirmar",
    "Reset" : "Reiniciar",
    "Cancel" : "Cancelar",
    "Copy link" : "Copiar liga",
    "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
    "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "¡Puedes invitar a otros usando la pestaña de participante de la barra lateral o compartiendo esta liga para invitar a otras personas!",
    "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
    "Mute audio" : "Silenciar audio",
    "Disable video" : "Deshabilitar video",
    "Enable video" : "Habilitar el video",
    "You" : "Tú",
    "Show screen" : "Mostrar pantalla",
    "Collapse" : "Colapsar",
    "Favorite" : "Hacer favorito",
    "Description" : "Descripción",
    "Restricted" : "Restringido",
    "Personal" : "Personal",
    "Permissions" : "Permisos",
    "Leave conversation" : "Dejar la conversación",
    "Delete conversation" : "Borrar conversación",
    "Submit" : "Enviar",
    "Password protection" : "Protección con contraseña",
    "Save" : "Guardar",
    "Edit" : "Editar",
    "Delete" : "Eliminar",
    "Password" : "Contraseña",
    "API token" : "Ficha del API",
    "Login" : "Iniciar sesión",
    "Nickname" : "Apodo",
    "Client ID" : "ID del cliente",
    "Notifications" : "Notificaciones",
    "Remove from favorites" : "Eliminar de favoritos",
    "Add to favorites" : "Agregar a favoritos",
    "Loading" : "Cargando",
    "Groups" : "Grupos",
    "Circles" : "Círculos",
    "Unread mentions" : "Menciones sin leer",
    "Password protect" : "Proteger con contraseña",
    "Close" : "Cerrar",
    "Conversation name" : "Nombre de la conversación",
    "Devices" : "Dispositivos",
    "Done" : "Terminado",
    "No audio" : "Sin audio",
    "Upload" : "Cargar",
    "Files" : "Archivos",
    "Invalid path selected" : "Ruta seleccionada no válida.",
    "Dismiss" : "Descartar",
    "Reply" : "Responder",
    "Translate" : "Traducir",
    "Contact" : "Contacto",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Group" : "Grupo",
    "Create new poll" : "Crear nueva encuesta",
    "New file" : "Archivo nuevo",
    "Blank" : "Vacío",
    "Settings" : "Configuraciones ",
    "Create poll" : "Crear encuesta",
    "Send" : "Enviar",
    "moderator" : "moderador",
    "guest" : "invitado",
    "Demote from moderator" : "Degradar de moderador",
    "Promote to moderator" : "Promover a moderador",
    "Remove participant" : "Eliminar participante",
    "Searching …" : "Buscando  …",
    "No results" : "Sin resultados",
    "Add users or groups" : "Agregar usuarios o grupos",
    "Participants" : "Participantes",
    "Chat" : "Chat",
    "Details" : "Detalles",
    "Privacy" : "Privacidad",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Search" : "Buscar",
    "Open sidebar" : "Abrir barra lateral",
    "Show your screen" : "Mostrar tu pantalla",
    "Stop screensharing" : "Dejar de compartir la pantalla",
    "Screensharing options" : "Opciones de compartir pantalla",
    "Enable screensharing" : "Habilitar compartir pantalla",
    "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
    "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
    "Grid view" : "Vista de cuadrícula",
    "No unread mentions" : "No hay menciones sin leer",
    "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
    "Media" : "Multimedia",
    "Polls" : "Encuestas",
    "Locations" : "Ubicaciones",
    "Audio" : "Audio",
    "Other" : "Otro",
    "Do not disturb" : "No molestar",
    "Away" : "Ausente",
    "Default" : "Predeterminado",
    "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
    "Please move your setup to HTTPS" : "Por favor cambia tu configuración a HTTPS",
    "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
    "WebRTC is not supported in your browser" : "WebRTC no está soportado en tu navegador",
    "Please use a different browser like Firefox or Chrome" : "Por favor usa un navegador diferente como Firefox o Chrome",
    "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
    "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
    "TURN server" : "Servidor TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. ",
    "%s Talk on your mobile devices" : "%s Habla en tus dispositivos móviles",
    "Android app" : "Aplicación Android",
    "iOS app" : "Aplicación iOS",
    "More actions" : "Más acciones",
    "Rename conversation" : "Renombrar conversación"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
